@@ -17,5 +17,7 @@
 #undef HAVE_FRIBIDI
 #undef HAVE_UNISTD_H
 #undef HAVE_FREETYPE_2_0_3
+#undef HAVE_USP10_H
 
 #undef MINI_XFTCONFIG_DIR
+#undef HAVE_XFT2
