@@ -28,30 +28,20 @@ struct _ThaiFontInfo
 {
   PangoFont       *font;
   ThaiFontSet      font_set;
-  ThaiFontInfoType info_type;
-  union {
-    PangoXSubfont subfont; /* THAI_FONTINFO_X */
-    gpointer      face;    /* THAI_FONTINFO_XFT */
-  } info;
+  PangoXSubfont    subfont; /* For X backend */
+
+  PangoGlyph
+  (*make_glyph) (ThaiFontInfo *font_info, unsigned int c);
+
+  PangoGlyph
+  (*make_unknown_glyph) (ThaiFontInfo *font_info, unsigned int c);
 };
 
-/*
- * Abstract methods
- */
-ThaiFontInfo *
-get_font_info (PangoFont *font);
-
-PangoGlyph
-make_glyph (ThaiFontInfo *font_info, unsigned int c);
-
-PangoGlyph
-make_unknown_glyph (ThaiFontInfo *font_info, unsigned int c);
-
 /*
  * Public functions
  */
 void
-thai_engine_shape (PangoFont        *font,
+thai_engine_shape (ThaiFontInfo     *font_info,
                    const char       *text,
                    gint              length,
                    PangoAnalysis    *analysis,
