@@ -97,8 +97,12 @@ struct _PangoAttribute
   guint end_index;
 };
 
+typedef gboolean (*PangoAttrFilterFunc) (PangoAttribute *attribute,
+					 gpointer        data);
+
 struct _PangoAttrClass
 {
+  /*< public >*/
   PangoAttrType type;
   PangoAttribute * (*copy) (const PangoAttribute *attr);
   void             (*destroy) (PangoAttribute *attr);
@@ -191,6 +195,11 @@ void               pango_attr_list_splice        (PangoAttrList  *list,
 						  PangoAttrList  *other,
 						  gint            pos,
 						  gint            len);
+
+PangoAttrList *pango_attr_list_filter (PangoAttrList       *list,
+				       PangoAttrFilterFunc  func,
+				       gpointer             data);
+
 PangoAttrIterator *pango_attr_list_get_iterator  (PangoAttrList  *list);
 
 void               pango_attr_iterator_range    (PangoAttrIterator     *iterator,
@@ -205,6 +214,7 @@ void               pango_attr_iterator_get_font (PangoAttrIterator     *iterator
                                                  PangoFontDescription  *desc,
 						 PangoLanguage        **language,
                                                  GSList               **extra_attrs);
+GSList *          pango_attr_iterator_get_attrs (PangoAttrIterator     *iterator);
 
 
 gboolean pango_parse_markup (const char                 *markup_text,
